@@ -3,16 +3,18 @@ from contextvars import copy_context
 from typing import Any
 
 from starlette_context import _request_scope_context_storage
+from starlette_context.errors import ContextDoesNotExistError
 
 
 class _Context(UserDict):
     """
     A mapping with dict-like interface.
-    It is using request context as a data store.
-    Can be used only if context has been created in the middleware.
+
+    It is using request context as a data store. Can be used only if context
+    has been created in the middleware.
     """
 
-    def __init__(self, *args: Any, **kwargs: Any):
+    def __init__(self, *args: Any, **kwargs: Any):  # noqa
         # not calling super on purpose
         if args or kwargs:
             raise AttributeError("Can't instantiate with attributes")
@@ -20,24 +22,20 @@ class _Context(UserDict):
     @property
     def data(self) -> dict:  # type: ignore
         """
-        Dump this to json. Object itself it not serializable.
+        Dump this to json.
+
+        Object itself it not serializable.
         """
         try:
             return _request_scope_context_storage.get()
-        except LookupError as e:
-            raise RuntimeError(
-                "You didn't use ContextMiddleware or "
-                "you're trying to access `context` object "
-                "outside of the request-response cycle."
-            ) from e
+        except LookupError:
+            raise ContextDoesNotExistError
 
     def exists(self) -> bool:
         return _request_scope_context_storage in copy_context()
 
     def copy(self) -> dict:  # type: ignore
-        """
-        Read only context data.
-        """
+        """Read only context data."""
         import copy
 
         return copy.copy(self.data)
